@@ -412,8 +412,9 @@ module.exports = class URDNA2015 extends AsyncAlgorithm {
                   // is greater than or equal to the length of chosen path and
                   // path is lexicographically greater than chosen path, then
                   // skip to the next permutation.
-                  if(chosenPath.length !== 0 &&
-                    path.length >= chosenPath.length && path > chosenPath) {
+                  // Note: Comparing path length to chosen path length can be
+                  // optimized away; only compare lexicographically.
+                  if(chosenPath.length !== 0 && path > chosenPath) {
                     // FIXME: may cause inaccurate total depth calculation
                     return nextPermutation();
                   }
@@ -446,8 +447,9 @@ module.exports = class URDNA2015 extends AsyncAlgorithm {
                     // path is greater than or equal to the length of chosen
                     // path and path is lexicographically greater than chosen
                     // path, then skip to the next permutation.
-                    if(chosenPath.length !== 0 &&
-                      path.length >= chosenPath.length && path > chosenPath) {
+                    // Note: Comparing path length to chosen path length can be
+                    // optimized away; only compare lexicographically.
+                    if(chosenPath.length !== 0 && path > chosenPath) {
                       // FIXME: may cause inaccurate total depth calculation
                       return nextPermutation();
                     }
